"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilePaste = void 0;
const prosemirror_model_1 = require("prosemirror-model");
const prosemirror_state_1 = require("prosemirror-state");
const base_1 = require("../../../extensions/base");
const utils_1 = require("../Clipboard/utils");
// Custom handler of pasted files to prevent insert a file preview in base64-format into editor's content
const FilePaste = (builder) => {
    builder.addPlugin(({ schema }) => {
        return new prosemirror_state_1.Plugin({
            props: {
                handlePaste(view, event) {
                    const { clipboardData } = event;
                    if (!clipboardData || !(0, utils_1.isFilesOnly)(clipboardData))
                        return false;
                    const nodes = [];
                    for (const file of Array.from(clipboardData.files)) {
                        nodes.push((0, base_1.pType)(schema).create(null, schema.text(file.name)));
                    }
                    view.dispatch(view.state.tr
                        .replaceSelection(new prosemirror_model_1.Slice(prosemirror_model_1.Fragment.from(nodes), 0, 0))
                        .scrollIntoView());
                    return true;
                },
            },
        });
    }, builder.Priority.Lowest);
};
exports.FilePaste = FilePaste;
