"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YfmFilePaste = void 0;
const prosemirror_state_1 = require("prosemirror-state");
const markdown_1 = require("../../../../extensions/markdown");
const lodash_1 = require("../../../../lodash");
const Clipboard_1 = require("../../Clipboard");
const utils_1 = require("../../ImgSizeAdditions/utils"); // TODO: remove hard import
const upload_1 = require("./upload");
const { isFilesOnly, isFilesFromHtml, isImageFile } = Clipboard_1.clipboardUtils;
const YfmFilePaste = (builder, opts) => {
    if (!opts || !(0, lodash_1.isFunction)(opts.fileUploadHandler))
        throw new Error('YfmFilePaste extension: fileUploadHandler is not a function');
    builder.addPlugin(() => new prosemirror_state_1.Plugin({
        props: {
            handleDOMEvents: {
                paste(view, e) {
                    const files = getPastedFiles(e.clipboardData);
                    if (files) {
                        e.preventDefault();
                        new YfmFilesPasteUploadProcess(view, files, {
                            uploadHandler: opts.fileUploadHandler,
                            needToSetDimensionsForUploadedImages: opts.needToSetDimensionsForUploadedImages,
                        }).run();
                        return true;
                    }
                    return false;
                },
            },
        },
    }), builder.Priority.Low);
};
exports.YfmFilePaste = YfmFilePaste;
function getPastedFiles(data) {
    if (!data)
        return null;
    if (!isFilesOnly(data) && !isFilesFromHtml(data))
        return null;
    return Array.from(data.files);
}
class YfmFilesPasteUploadProcess extends upload_1.YfmFilesUploadProcessBase {
    constructor(view, files, opts) {
        super(view, files, opts.uploadHandler);
        const { schema } = this.view.state;
        if ((0, markdown_1.imageType)(schema)) {
            this.createImage = (0, utils_1.createImageNode)((0, markdown_1.imageType)(schema), {
                needDimmensions: opts.needToSetDimensionsForUploadedImages,
            });
        }
    }
    getSkeletonInitPos() {
        return this.view.state.tr.selection.from;
    }
    async createPMNode(res) {
        return isImageFile(res.file) && this.createImage
            ? this.createImage(res)
            : this.createFile(res);
    }
}
