import { decode as base64ToBuffer } from 'base64-arraybuffer';
import { Plugin } from 'prosemirror-state';
import { ImgSizeAttr } from '../../../../extensions/specs';
import { isFunction } from '../../../../lodash';
import { clipboardUtils } from '../../Clipboard';
import { isImageNode } from '../utils';
import { ImagesUploadProcess } from './upload';
const { isFilesFromHtml, isFilesOnly, isImageFile } = clipboardUtils;
export const ImagePaste = (builder, opts) => {
    if (!opts || !isFunction(opts.imageUploadHandler))
        throw new Error('ImagePaste extension: imageUploadHandler is not a function');
    builder.addPlugin(() => new Plugin({
        props: {
            handleDOMEvents: {
                paste(view, e) {
                    const files = getPastedImages(e.clipboardData);
                    if (files) {
                        e.preventDefault();
                        new ImagesUploadProcess(view, files, opts.imageUploadHandler, view.state.tr.selection.from, opts).run();
                        return true;
                    }
                    return false;
                },
            },
            handlePaste(view, _event, slice) {
                const node = sliceSingleNode(slice);
                if (node && isImageNode(node)) {
                    const imgUrl = node.attrs[ImgSizeAttr.Src];
                    const imgFile = dataUrlToFile(imgUrl, 'image');
                    if (imgFile) {
                        new ImagesUploadProcess(view, [imgFile], opts.imageUploadHandler, view.state.tr.selection.from, opts).run();
                        return true;
                    }
                }
                return false;
            },
        },
    }), builder.Priority.High);
};
function getPastedImages(data) {
    if (!data || data.files.length === 0)
        return null;
    if (!isFilesOnly(data) && !isFilesFromHtml(data))
        return null;
    const files = Array.from(data.files);
    return files.every(isImageFile) ? files : null;
}
// copied from prosemirror-view input.ts
function sliceSingleNode(slice) {
    return slice.openStart === 0 && slice.openEnd === 0 && slice.content.childCount === 1
        ? slice.content.firstChild
        : null;
}
function dataUrlToFile(dataUrl, filename) {
    var _a;
    const [data, base64String] = dataUrl.split(',');
    if (!data || !base64String)
        return null;
    const mime = (_a = data.match(/^data:(.+);base64/)) === null || _a === void 0 ? void 0 : _a[1];
    if (!mime)
        return null;
    return new File([base64ToBuffer(base64String)], filename, { type: mime });
}
