import { Plugin } from 'prosemirror-state';
import { imageType } from '../../../../extensions/markdown';
import { isFunction } from '../../../../lodash';
import { clipboardUtils } from '../../Clipboard';
import { createImageNode } from '../../ImgSizeAdditions/utils'; // TODO: remove hard import
import { YfmFilesUploadProcessBase } from './upload';
const { isFilesOnly, isFilesFromHtml, isImageFile } = clipboardUtils;
export const YfmFilePaste = (builder, opts) => {
    if (!opts || !isFunction(opts.fileUploadHandler))
        throw new Error('YfmFilePaste extension: fileUploadHandler is not a function');
    builder.addPlugin(() => new Plugin({
        props: {
            handleDOMEvents: {
                paste(view, e) {
                    const files = getPastedFiles(e.clipboardData);
                    if (files) {
                        e.preventDefault();
                        new YfmFilesPasteUploadProcess(view, files, {
                            uploadHandler: opts.fileUploadHandler,
                            needToSetDimensionsForUploadedImages: opts.needToSetDimensionsForUploadedImages,
                        }).run();
                        return true;
                    }
                    return false;
                },
            },
        },
    }), builder.Priority.Low);
};
function getPastedFiles(data) {
    if (!data)
        return null;
    if (!isFilesOnly(data) && !isFilesFromHtml(data))
        return null;
    return Array.from(data.files);
}
class YfmFilesPasteUploadProcess extends YfmFilesUploadProcessBase {
    constructor(view, files, opts) {
        super(view, files, opts.uploadHandler);
        const { schema } = this.view.state;
        if (imageType(schema)) {
            this.createImage = createImageNode(imageType(schema), {
                needDimmensions: opts.needToSetDimensionsForUploadedImages,
            });
        }
    }
    getSkeletonInitPos() {
        return this.view.state.tr.selection.from;
    }
    async createPMNode(res) {
        return isImageFile(res.file) && this.createImage
            ? this.createImage(res)
            : this.createFile(res);
    }
}
